@@ -64,3 +64,37 @@
 #' resolution in situ. Cell. 2021 Jan 21;184(2):545-559.e22. doi: 10.1016/j.cell.2020.12.021.
 #' Epub 2020 Dec 23. PMID: 33357446; PMCID: PMC7836100.
 "ptsi_pgk"
+
+#' List of metals 
+#'
+#' A list of all metals and metalloids in the periodic table.
+#'
+#' @format A data.frame containing the columns \code{atomic_number}, \code{symbol}, \code{name},
+#' \code{type}, \code{chebi_id}.
+#' @source https://en.wikipedia.org/wiki/Metal and https://en.wikipedia.org/wiki/Metalloid
+"metal_list"
+
+#' List of metal-related ChEBI IDs in UniProt
+#'
+#' A list that contains all ChEBI IDs that appear in UniProt and that contain either a metal atom
+#' in their formula or that do not have a formula but the ChEBI term is related to metals.
+#' This was last updated on the 22/08/11.
+#'
+#' @format A data.frame containing information retrieved from ChEBI using `fetch_chebi(stars = c(2, 3))`, 
+#' filtered using symbols in the `metal_list` and manual annotation of metal related ChEBI IDs that do not 
+#' contain a formula.
+#' @source UniProt (cc_cofactor, cc_catalytic_activity, ft_binding) and ChEBI
+"metal_chebi_uniprot"
+
+#' Molecular function gene ontology metal subset
+#'
+#' A subset of molecular function gene ontology terms related to metals that was created 
+#' using the slimming process provided by the QuickGO EBI database. 
+#' This was last updated on the 22/06/07.
+#'
+#' @format A data.frame containing a slim subset of molecular function gene ontology terms
+#' that are related to metal binding. The `slims_from_id` column contains all IDs relevant 
+#' in this subset while the `slims_to_ids` column contains the starting IDs. If ChEBI IDs
+#' have been annotated manually this is indicated in the `database` column.
+#' @source QuickGO and ChEBI
+"metal_go_slim_subset"
\ No newline at end of file
