@@ -141,59 +141,59 @@ fetch_alphafold_prediction <- function(uniprot_ids = NULL,
     ))
 
     organism_file <- switch(organism_name,
-      "Arabidopsis thaliana" = "UP000006548_3702_ARATH.tar",
-      "Caenorhabditis elegans" = "UP000001940_6239_CAEEL.tar",
-      "Candida albicans" = "UP000000559_237561_CANAL.tar",
-      "Danio rerio" = "UP000000437_7955_DANRE.tar",
-      "Dictyostelium discoideum" = "UP000002195_44689_DICDI.tar",
-      "Drosophila melanogaster" = "UP000000803_7227_DROME.tar",
-      "Escherichia coli" = "UP000000625_83333_ECOLI.tar",
-      "Glycine max" = "UP000008827_3847_SOYBN.tar",
-      "Homo sapiens" = "UP000005640_9606_HUMAN.tar",
-      "Leishmania infantum" = "UP000008153_5671_LEIIN.tar",
-      "Methanocaldococcus jannaschii" = "UP000000805_243232_METJA.tar",
-      "Mus musculus" = "UP000000589_10090_MOUSE.tar",
-      "Mycobacterium tuberculosis" = "UP000001584_83332_MYCTU.tar",
-      "Oryza sativa" = "UP000059680_39947_ORYSJ.tar",
-      "Plasmodium falciparum" = "UP000001450_36329_PLAF7.tar",
-      "Rattus norvegicus" = "UP000002494_10116_RAT.tar",
-      "Saccharomyces cerevisiae" = "UP000002311_559292_YEAST.tar",
-      "Schizosaccharomyces pombe" = "UP000002485_284812_SCHPO.tar",
-      "Staphylococcus aureus" = "UP000008816_93061_STAA8.tar",
-      "Trypanosoma cruzi" = "UP000002296_353153_TRYCC.tar",
-      "Zea mays" = "UP000007305_4577_MAIZE.tar",
-      "Ajellomyces capsulatus" = "UP000001631_447093_AJECG_v2.tar",
-      "Brugia malayi" = "UP000006672_6279_BRUMA_v2.tar",
-      "Campylobacter jejuni" = "UP000000799_192222_CAMJE_v2.tar",
-      "Cladophialophora carrionii" = "UP000094526_86049_9EURO1_v2.tar",
-      "Dracunculus medinensis" = "UP000274756_318479_DRAME_v2.tar",
-      "Enterococcus faecium" = "UP000325664_1352_ENTFC_v2.tar",
-      "Fonsecaea pedrosoi" = "UP000053029_1442368_9EURO2_v2.tar",
-      "Haemophilus influenzae" = "UP000000579_71421_HAEIN_v2.tar",
-      "Helicobacter pylori" = "UP000000429_85962_HELPY_v2.tar",
-      "Klebsiella pneumoniae" = "UP000007841_1125630_KLEPH_v2.tar",
-      "Leishmania infantum" = "UP000008153_5671_LEIIN_v2.tar",
-      "Madurella mycetomatis" = "UP000078237_100816_9PEZI1_v2.tar",
-      "Mycobacterium leprae" = "UP000000806_272631_MYCLE_v2.tar",
-      "Mycobacterium tuberculosis" = "UP000001584_83332_MYCTU_v2.tar",
-      "Mycobacterium ulcerans" = "UP000020681_1299332_MYCUL_v2.tar",
-      "Neisseria gonorrhoeae" = "UP000000535_242231_NEIG1_v2.tar",
-      "Nocardia brasiliensis" = "UP000006304_1133849_9NOCA1_v2.tar",
-      "Onchocerca volvulus" = "UP000024404_6282_ONCVO_v2.tar",
-      "Paracoccidioides lutzii" = "UP000002059_502779_PARBA_v2.tar",
-      "Plasmodium falciparum" = "UP000001450_36329_PLAF7_v2.tar",
-      "Pseudomonas aeruginosa" = "UP000002438_208964_PSEAE_v2.tar",
-      "Salmonella typhimurium" = "UP000001014_99287_SALTY_v2.tar",
-      "Schistosoma mansoni" = "UP000008854_6183_SCHMA_v2.tar",
-      "Shigella dysenteriae" = "UP000002716_300267_SHIDS_v2.tar",
-      "Sporothrix schenckii" = "UP000018087_1391915_SPOS1_v2.tar",
-      "Staphylococcus aureus" = "UP000008816_93061_STAA8_v2.tar",
-      "Streptococcus pneumoniae" = "UP000000586_171101_STRR6_v2.tar",
-      "Strongyloides stercoralis" = "UP000035681_6248_STRER_v2.tar",
-      "Trichuris trichiura" = "UP000030665_36087_TRITR_v2.tar",
-      "Trypanosoma brucei" = "UP000008524_185431_TRYB2_v2.tar",
-      "Trypanosoma cruzi" = "UP000002296_353153_TRYCC_v2.tar",
-      "Wuchereria bancrofti" = "UP000270924_6293_WUCBA_v2.tar"
+      "Arabidopsis thaliana" = "UP000006548_3702_ARATH_v3.tar",
+      "Caenorhabditis elegans" = "UP000001940_6239_CAEEL_v3.tar",
+      "Candida albicans" = "UP000000559_237561_CANAL_v3.tar",
+      "Danio rerio" = "UP000000437_7955_DANRE_v3.tar",
+      "Dictyostelium discoideum" = "UP000002195_44689_DICDI_v3.tar",
+      "Drosophila melanogaster" = "UP000000803_7227_DROME_v3.tar",
+      "Escherichia coli" = "UP000000625_83333_ECOLI_v3.tar",
+      "Glycine max" = "UP000008827_3847_SOYBN_v3.tar",
+      "Homo sapiens" = "UP000005640_9606_HUMAN_v3.tar",
+      "Leishmania infantum" = "UP000008153_5671_LEIIN_v3.tar",
+      "Methanocaldococcus jannaschii" = "UP000000805_243232_METJA_v3.tar",
+      "Mus musculus" = "UP000000589_10090_MOUSE_v3.tar",
+      "Mycobacterium tuberculosis" = "UP000001584_83332_MYCTU_v3.tar",
+      "Oryza sativa" = "UP000059680_39947_ORYSJ_v3.tar",
+      "Plasmodium falciparum" = "UP000001450_36329_PLAF7_v3.tar",
+      "Rattus norvegicus" = "UP000002494_10116_RAT_v3.tar",
+      "Saccharomyces cerevisiae" = "UP000002311_559292_YEAST_v3.tar",
+      "Schizosaccharomyces pombe" = "UP000002485_284812_SCHPO_v3.tar",
+      "Staphylococcus aureus" = "UP000008816_93061_STAA8_v3.tar",
+      "Trypanosoma cruzi" = "UP000002296_353153_TRYCC_v3.tar",
+      "Zea mays" = "UP000007305_4577_MAIZE_v3.tar",
+      "Ajellomyces capsulatus" = "UP000001631_447093_AJECG_v3.tar",
+      "Brugia malayi" = "UP000006672_6279_BRUMA_v3.tar",
+      "Campylobacter jejuni" = "UP000000799_192222_CAMJE_v3.tar",
+      "Cladophialophora carrionii" = "UP000094526_86049_9EURO1_v3.tar",
+      "Dracunculus medinensis" = "UP000274756_318479_DRAME_v3.tar",
+      "Enterococcus faecium" = "UP000325664_1352_ENTFC_v3.tar",
+      "Fonsecaea pedrosoi" = "UP000053029_1442368_9EURO2_v3.tar",
+      "Haemophilus influenzae" = "UP000000579_71421_HAEIN_v3.tar",
+      "Helicobacter pylori" = "UP000000429_85962_HELPY_v3.tar",
+      "Klebsiella pneumoniae" = "UP000007841_1125630_KLEPH_v3.tar",
+      "Leishmania infantum" = "UP000008153_5671_LEIIN_v3.tar",
+      "Madurella mycetomatis" = "UP000078237_100816_9PEZI1_v3.tar",
+      "Mycobacterium leprae" = "UP000000806_272631_MYCLE_v3.tar",
+      "Mycobacterium tuberculosis" = "UP000001584_83332_MYCTU_v3.tar",
+      "Mycobacterium ulcerans" = "UP000020681_1299332_MYCUL_v3.tar",
+      "Neisseria gonorrhoeae" = "UP000000535_242231_NEIG1_v3.tar",
+      "Nocardia brasiliensis" = "UP000006304_1133849_9NOCA1_v3.tar",
+      "Onchocerca volvulus" = "UP000024404_6282_ONCVO_v3.tar",
+      "Paracoccidioides lutzii" = "UP000002059_502779_PARBA_v3.tar",
+      "Plasmodium falciparum" = "UP000001450_36329_PLAF7_v3.tar",
+      "Pseudomonas aeruginosa" = "UP000002438_208964_PSEAE_v3.tar",
+      "Salmonella typhimurium" = "UP000001014_99287_SALTY_v3.tar",
+      "Schistosoma mansoni" = "UP000008854_6183_SCHMA_v3.tar",
+      "Shigella dysenteriae" = "UP000002716_300267_SHIDS_v3.tar",
+      "Sporothrix schenckii" = "UP000018087_1391915_SPOS1_v3.tar",
+      "Staphylococcus aureus" = "UP000008816_93061_STAA8_v3.tar",
+      "Streptococcus pneumoniae" = "UP000000586_171101_STRR6_v3.tar",
+      "Strongyloides stercoralis" = "UP000035681_6248_STRER_v3.tar",
+      "Trichuris trichiura" = "UP000030665_36087_TRITR_v3.tar",
+      "Trypanosoma brucei" = "UP000008524_185431_TRYB2_v3.tar",
+      "Trypanosoma cruzi" = "UP000002296_353153_TRYCC_v3.tar",
+      "Wuchereria bancrofti" = "UP000270924_6293_WUCBA_v3.tar"
     )
 
     url <- paste0("https://ftp.ebi.ac.uk/pub/databases/alphafold/latest/", organism_file)
