@@ -2,10 +2,11 @@
 #'
 #' Fetches proteome data from UniProt for the provided organism ID.
 #'
-#' @param organism_id a numeric value that specifies the NCBI taxonomy identifier (TaxId) for and
+#' @param organism_id a numeric value that specifies the NCBI taxonomy identifier (TaxId) for an
 #' organism.
 #' @param columns a character vector of metadata columns that should be imported from UniProt (all
-#' possible columns can be found here: https://www.uniprot.org/help/uniprotkb_column_names).
+#' possible columns can be found \href{https://www.uniprot.org/help/return_fields}{here}. For 
+#' cross-referenced database provide the database name with the prefix "xref_", e.g. \code{"xref_pdb"}).
 #' Note: Not more than one or two columns should be selected otherwise the function will not be
 #' able to efficiently retrieve the information. If more information is needed, \code{fetch_uniprot()}
 #' can be used with the IDs retrieved by this function.
@@ -22,28 +23,29 @@
 #' }
 fetch_uniprot_proteome <-
   function(organism_id,
-           columns = c("id"),
+           columns = c("accession"),
            reviewed = TRUE) {
     if (length(organism_id) == 0) {
       stop("No valid organism ID found.")
     }
-    if (length(columns) > 3) {
-      warning(strwrap("We suggest to use the fetch_uniprot function to fetch more than three columns.",
+    message("Please note that some column names have changed due to UniProt updating its API! This might cause errors in your code. You can fix it by replacing the old column names with new ones.")
+    if (length(columns) > 4) {
+      warning(strwrap("We suggest to use the fetch_uniprot function to fetch more than four columns.",
         prefix = "\n", initial = ""
       ))
     }
-    url <- "http://legacy.uniprot.org/uniprot/?query="
+    url <- "http://rest.uniprot.org/uniprotkb/stream?query="
     column_names <- janitor::make_clean_names(columns)
     collapsed_columns <- paste(columns, collapse = ",")
-    reviewed <- paste0("reviewed:", ifelse(reviewed == TRUE, "yes", "no"))
-    organism_id <- paste0("organism:", organism_id)
+    reviewed <- paste0("reviewed:", ifelse(reviewed == TRUE, "true", "false"))
+    organism_id <- paste0("organism_id:", organism_id)
     query_url <-
       utils::URLencode(paste0(
         url,
         reviewed,
         "+AND+",
         organism_id,
-        "&format=tab&columns=",
+        "&format=tsv&fields=",
         collapsed_columns
       ))
     result <- try_query(query_url, progress = FALSE, show_col_types = FALSE)
