@@ -7,10 +7,10 @@ if (Sys.getenv("TEST_PROTTI") == "true") {
     expect_warning(uniprot <- fetch_uniprot(unis))
     expect_is(uniprot, "data.frame")
     expect_equal(nrow(uniprot), 9)
-    expect_equal(ncol(uniprot), 18)
+    expect_equal(ncol(uniprot), 17)
   })
 
-  proteome <- fetch_uniprot_proteome(organism_id = "83333", columns = c("id", "go(molecular function)", "database(String)"))
+  proteome <- fetch_uniprot_proteome(organism_id = "83333", columns = c("accession", "go_f", "xref_string"))
   test_that("fetch_uniprot_proteome works", {
     expect_is(proteome, "data.frame")
     expect_equal(ncol(proteome), 3)
@@ -25,7 +25,7 @@ if (Sys.getenv("TEST_PROTTI") == "true") {
     expect_equal(ncol(mobidb), 7)
   })
 
-  database <- fetch_chebi()
+  database <- fetch_chebi(stars = c(2, 3))
   relations <- fetch_chebi(relation = TRUE)
   test_that("fetch_chebi works", {
     expect_is(database, "data.frame")
@@ -63,8 +63,8 @@ if (Sys.getenv("TEST_PROTTI") == "true") {
   test_that("fetch_pdb works", {
     pdb <- fetch_pdb(pdb_ids)
     expect_is(pdb, "data.frame")
-    expect_equal(nrow(pdb), 34)
-    expect_equal(ncol(pdb), 32)
+    expect_equal(nrow(pdb), 36)
+    expect_equal(ncol(pdb), 46)
   })
 
   test_that("fetch_pdb_structure works", {
@@ -98,15 +98,6 @@ if (Sys.getenv("TEST_PROTTI") == "true") {
     expect_equal(ncol(metal_pdb), 25)
   })
 
-  test_that("extract_metal_binders works", {
-    data_uniprot <- fetch_uniprot(c("Q03640", "Q03778", "P22276", "P25889"))
-    metal_info <- extract_metal_binders(data = data_uniprot, chebi_data = database, chebi_relation_data = relations)
-
-    expect_is(metal_info, "data.frame")
-    expect_equal(ncol(metal_info), 9)
-    expect_gt(nrow(metal_info), 110)
-  })
-
   test_that("deprecated kegg_enrichment works", {
     # first fake significances are generated based on the first 10 rows of every group
     kegg_input <- kegg %>%
@@ -181,14 +172,14 @@ if (Sys.getenv("TEST_PROTTI") == "true") {
 
   test_that("deprecated go_enrichment works", {
     go_input <- proteome %>%
-      dplyr::distinct(.data$id, .data$go_molecular_function) %>%
-      dplyr::mutate(is_significant = ifelse((match(.data$id, .data$id) <= 500), TRUE, FALSE)) %>%
+      dplyr::distinct(.data$accession, .data$go_f) %>%
+      dplyr::mutate(is_significant = ifelse((match(.data$accession, .data$accession) <= 500), TRUE, FALSE)) %>%
       dplyr::slice(1:3000)
 
     rlang::with_options(lifecycle_verbosity = "warning", {
       expect_warning(go_enriched <- go_enrichment(
         data = go_input,
-        protein_id = id,
+        protein_id = accession,
         is_significant = is_significant,
         ontology_type = "MF",
         organism_id = "83333",
@@ -203,7 +194,7 @@ if (Sys.getenv("TEST_PROTTI") == "true") {
     rlang::with_options(lifecycle_verbosity = "warning", {
       expect_warning(go_enriched_data <- go_enrichment(
         data = go_input,
-        protein_id = id,
+        protein_id = accession,
         is_significant = is_significant,
         ontology_type = "MF",
         go_data = go_eco,
@@ -218,9 +209,9 @@ if (Sys.getenv("TEST_PROTTI") == "true") {
     rlang::with_options(lifecycle_verbosity = "warning", {
       expect_warning(go_enriched_uniprot <- go_enrichment(
         data = go_input,
-        protein_id = id,
+        protein_id = accession,
         is_significant = is_significant,
-        go_annotations_uniprot = go_molecular_function,
+        go_annotations_uniprot = go_f,
         plot = FALSE
       ))
     })
@@ -232,7 +223,7 @@ if (Sys.getenv("TEST_PROTTI") == "true") {
     rlang::with_options(lifecycle_verbosity = "warning", {
       expect_warning(p <- go_enrichment(
         data = go_input,
-        protein_id = id,
+        protein_id = accession,
         is_significant = is_significant,
         ontology_type = "MF",
         organism_id = "83333",
@@ -246,13 +237,13 @@ if (Sys.getenv("TEST_PROTTI") == "true") {
 
   test_that("calculate_go_enrichment works", {
     go_input <- proteome %>%
-      dplyr::distinct(.data$id, .data$go_molecular_function) %>%
-      dplyr::mutate(is_significant = ifelse((match(.data$id, .data$id) <= 500), TRUE, FALSE)) %>%
+      dplyr::distinct(.data$accession, .data$go_f) %>%
+      dplyr::mutate(is_significant = ifelse((match(.data$accession, .data$accession) <= 500), TRUE, FALSE)) %>%
       dplyr::slice(1:3000)
 
     go_enriched <- calculate_go_enrichment(
       data = go_input,
-      protein_id = id,
+      protein_id = accession,
       is_significant = is_significant,
       ontology_type = "MF",
       organism_id = "83333",
@@ -265,7 +256,7 @@ if (Sys.getenv("TEST_PROTTI") == "true") {
 
     go_enriched_data <- calculate_go_enrichment(
       data = go_input,
-      protein_id = id,
+      protein_id = accession,
       is_significant = is_significant,
       ontology_type = "MF",
       go_data = go_eco,
@@ -278,9 +269,9 @@ if (Sys.getenv("TEST_PROTTI") == "true") {
 
     go_enriched_uniprot <- calculate_go_enrichment(
       data = go_input,
-      protein_id = id,
+      protein_id = accession,
       is_significant = is_significant,
-      go_annotations_uniprot = go_molecular_function,
+      go_annotations_uniprot = go_f,
       plot = FALSE
     )
 
@@ -290,7 +281,7 @@ if (Sys.getenv("TEST_PROTTI") == "true") {
 
     p <- calculate_go_enrichment(
       data = go_input,
-      protein_id = id,
+      protein_id = accession,
       is_significant = is_significant,
       ontology_type = "MF",
       organism_id = "83333",
@@ -380,8 +371,8 @@ if (Sys.getenv("TEST_PROTTI") == "true") {
     rlang::with_options(lifecycle_verbosity = "warning", {
       expect_warning(network <- network_analysis(
         data = input_many,
-        protein_id = id,
-        string_id = database_string,
+        protein_id = accession,
+        string_id = xref_string,
         organism_id = 511145,
         score_threshold = 900,
         binds_treatment = is_known,
@@ -395,8 +386,8 @@ if (Sys.getenv("TEST_PROTTI") == "true") {
     rlang::with_options(lifecycle_verbosity = "warning", {
       expect_warning(expect_error(network_analysis(
         data = input,
-        protein_id = id,
-        string_id = database_string,
+        protein_id = accession,
+        string_id = xref_string,
         organism_id = 511145,
         score_threshold = 900,
         binds_treatment = is_known,
@@ -417,8 +408,8 @@ if (Sys.getenv("TEST_PROTTI") == "true") {
 
     network <- analyse_functional_network(
       data = input_many,
-      protein_id = id,
-      string_id = database_string,
+      protein_id = accession,
+      string_id = xref_string,
       organism_id = 511145,
       score_threshold = 900,
       binds_treatment = is_known,
@@ -430,8 +421,8 @@ if (Sys.getenv("TEST_PROTTI") == "true") {
 
     expect_error(analyse_functional_network(
       data = input,
-      protein_id = id,
-      string_id = database_string,
+      protein_id = accession,
+      string_id = xref_string,
       organism_id = 511145,
       score_threshold = 900,
       binds_treatment = is_known,
@@ -439,13 +430,13 @@ if (Sys.getenv("TEST_PROTTI") == "true") {
     ), NA)
   })
 
+  eco <- fetch_eco()
+  eco_relation <- fetch_eco(return_relation = TRUE)
   test_that("fetch_eco works", {
-    eco <- fetch_eco()
     expect_is(eco, "data.frame")
     expect_gt(nrow(eco), 2300)
     expect_equal(ncol(eco), 10)
 
-    eco_relation <- fetch_eco(return_relation = TRUE)
     expect_is(eco_relation, "data.frame")
     expect_gt(nrow(eco_relation), 3200)
     expect_equal(ncol(eco_relation), 3)
@@ -457,4 +448,47 @@ if (Sys.getenv("TEST_PROTTI") == "true") {
 
     expect_error(fetch_eco(return_relation = TRUE, return_history = TRUE))
   })
-}
+  
+  uniprot_ids <- c("P00393", "P06129", "A0A0C5Q309", "A0A0C9VD04")
+  annotations <- fetch_quickgo(type = "annotations", id = uniprot_ids, ontology = "molecular_function")
+  test_that("fetch_quickgo works", {
+    expect_is(annotations, "data.frame")
+    expect_equal(nrow(annotations), 22)
+    expect_equal(ncol(annotations), 15)
+    
+    terms <- fetch_quickgo(type = "terms")
+    expect_is(terms, "data.frame")
+    expect_equal(nrow(terms), 47916)
+    expect_equal(ncol(terms), 13)
+
+    slims <- fetch_quickgo(type = "slims", go_id_slims = c("GO:0046872", "GO:0051540"))
+    expect_is(slims, "data.frame")
+    expect_equal(nrow(slims), 43)
+    expect_equal(ncol(slims), 2)
+    
+    expect_warning(fetch_quickgo(type = "annotations", 
+                               id = c("P63328","Q4FFP4"), 
+                               ontology = "molecular_function", 
+                               go_id_slims = c("GO:0046872", "GO:0051540")))
+  })
+  
+  test_that("extract_metal_binders works", {
+    data_uniprot <- fetch_uniprot(uniprot_ids,
+                                  columns = c(
+                                    "ft_binding",
+                                    "cc_cofactor",
+                                    "cc_catalytic_activity"
+                                  ))
+    
+    metal_info <- extract_metal_binders(data_uniprot = data_uniprot,
+                                        data_quickgo = annotations,
+                                        data_chebi = database,
+                                        data_chebi_relation = relations,
+                                        data_eco = eco,
+                                        data_eco_relation = eco_relation)
+    
+    expect_is(metal_info, "data.frame")
+    expect_equal(ncol(metal_info), 20)
+    expect_equal(nrow(metal_info), 34)
+  })
+}
\ No newline at end of file
